#!/bin/sh

#######################################################################
# A simple shell-script to install the Quake2 Missionpack Ground Zero #
# to /usr/share/games/quake2/ to be played with yamagi-quake2 or any  #
# other debian compliant Quake2 port installation.                    #
# It currently supports an (the?) original Q2:Ground Zero Game CD and #
# the Quake4 Bonus DVD, which contains Quake2 and its Missionpacks.   #
#                                                                     #
# It's (C) 2009 Daniel Gibson (metalcaedes@gmail.com) and may be      #
# freely used, altered and redistributed under the terms of the GPLv2 #
#######################################################################

CDROMDIR=$1
QUAKE2DIR="/usr/share/games/quake2"

if [ -z $CDROMDIR ]; then
	echo "Usage: install-ground_zero-rogue.sh [CD Mountpoint]"
	echo ""
	echo "Example: ./install-ground_zero-rogue.sh /cdrom"
	echo "If your Q2: Ground Zero CD is mounted to /cdrom"
	echo "Another typical mountpoint would be /media/cdrom"
	echo ""
	echo "You probably want to run this script as root or via sudo."
	
	exit 1
fi

# create dir
mkdir -p $QUAKE2DIR/rogue/video

# original q2: ground zero cd
if [ -e $CDROMDIR/Data/all/pak0.pak ]; then
	echo "Copying game data.."
	
	install -m 644 $CDROMDIR/Data/all/pak0.pak $QUAKE2DIR/rogue/
	install -m 644 $CDROMDIR/Data/max/Rogue/video/* $QUAKE2DIR/rogue/video/
else 
	# Q4 Bonus DVD
	if [ -e $CDROMDIR/setup/Data/rogue/pak0.pak ]; then
		echo "Copying game data.."
		
		install -m 644 $CDROMDIR/setup/Data/rogue/pak0.pak $QUAKE2DIR/rogue/
		install -m 644 $CDROMDIR/setup/Data/rogue/video/* $QUAKE2DIR/rogue/video/
	else
		# unknown/wrong CD
		echo "Can't find game data in $CDROMDIR!"
		echo "Did you specify the right CD Mountpoint?"
		echo "Are you sure that the Q2: Ground Zero Disc is mounted?"
		echo ""
		echo "This script should work with the original Q2: Ground Zero CD"
		echo "and the Quake4 Bonus DVD containing Quake2 and its Missionpacks."
		echo "If it doesn't, your game disc might differ from the ones that are"
		echo "known to the maintainer. Please contact him so he can update the script."
		echo "His E-Mail is: metalcaedes@gmail.com"
		
		exit 1
	fi
fi

if [ ! -e $QUAKE2DIR/rogue/pak0.pak ] ; then
	echo "Something went wrong: I can't find the files I was supposed to install on disc."
	echo "Maybe this script didn't have proper writing permissions to $QUAKE2DIR ?"
	echo "This will most probably be the case when it isn't run as root or via sudo."
	exit 1
fi

if [ ! -e $QUAKE2DIR/rogue/video/logo.cin ] ; then
	echo "It seems like the videos couldn't be installed properly (but pak0.pak could)."
	echo "You might have a game disc that differs from the ones known to the maintainer."
	echo "Please contact him so he can update this script: metalcaedes@gmail.com"
	exit 1
fi

echo "Quake2 MissionPack 2: Ground Zero was successfully installed to $QUAKE2DIR/rogue/!"
